# -*- coding: utf-8 -*-

from django.conf import settings
from django.test import TestCase
import codecs

from ..models import BBCode
from attachments.tests import with_temporary_manager, GIF_DATA


class FakeTextFile(object):
    def __init__(self):
        self.name = "test.txt"

    def chunks(self):
        yield b"abcd"


class FakeImageFile(object):
    def __init__(self):
        self.name = "test.gif"

    def chunks(self):
        yield codecs.decode(GIF_DATA, "base64")


class AttachDisplayTestCase(TestCase):
    @with_temporary_manager
    def test_attached_text(self, mgr):
        attachment = mgr.upload_file("my_namespace", FakeTextFile())

        ident = attachment.ident_main
        bbcode_text = f"x[attach]{ident}[/attach]"

        bbcode = BBCode("message_attach", "\x01" + bbcode_text, from_db=True)
        self.assertEqual(str(bbcode), bbcode_text)
        self.assertEqual(bbcode.as_text(), "x")
        self.assertHTMLEqual(
            bbcode.as_html(),
            f"""x<div class="inline_attachment">
                <img src="/static/bbcode/file_extension_txt.png" />
                <div><a href="{settings.MEDIA_URL}attachments/my_namespace/{ident}.txt">test.txt</a>
                </div>
                Taille : 4 octets
            </div>""",
        )

    @with_temporary_manager
    def test_attached_image(self, mgr):
        attachment = mgr.upload_file("my_namespace", FakeImageFile())

        ident = attachment.ident_main
        ident_mini = attachment.ident_mini
        bbcode_text = f"x[attach]{ident}[/attach]"

        bbcode = BBCode("message_attach", "\x01" + bbcode_text, from_db=True)

        self.assertEqual(str(bbcode), bbcode_text)
        self.assertEqual(bbcode.as_text(), "x")
        self.assertHTMLEqual(
            bbcode.as_html(),
            f"""x<a href="{settings.MEDIA_URL}attachments/my_namespace/{ident}.gif"><img
                src="{settings.MEDIA_URL}attachments/my_namespace/{ident_mini}.gif" alt=""></a>""",
        )

    def test_invalid_attachment(self):
        bbcode_text = "x[attach]invalid attachment[/attach]"

        bbcode = BBCode("message_attach", "\x01" + bbcode_text, from_db=True)
        self.assertEqual(str(bbcode), bbcode_text)
        self.assertEqual(bbcode.as_text(), "x")
        self.assertHTMLEqual(bbcode.as_html(), "x")
